@@ -26,5 +26,7 @@ def fix_uid(project, uid=None):
     if project.state:
         c.save_as_base()
     else:
-        logging.debug("Image id: %s", c.image['Id'])
+        project.context['image_id'] = c.image['Id']
     logging.info("UID for user '%s' set to %s", project.docker_user, uid)
+    return c.image['Id']
+
